@@ -73,7 +73,7 @@ class _CognitoAuth(AuthBase):
             cognito = login(
                 username=environ.get("NND_USERNAME"),
                 password=environ.get("NND_PASSWORD"),
-                userpool_id=user_pool_id,
+                user_pool_id=user_pool_id,
                 client_id=client_id,
             )
         else:
@@ -114,9 +114,13 @@ class NominodeAuth(_CognitoAuth):
             nominode_config.get("nomitall_api_url", "https://user.api.nomnomdata.com")
         )
 
-        if not self.have_credentials(config["COGNITO_USERPOOL_ID"]):
+        if (
+            not environ.get("NND_USERNAME")
+            and not environ.get("NND_PASSWORD")
+            and not self.have_credentials(config["COGNITO_USERPOOL_ID"])
+        ):
             raise click.ClickException(
-                f'Could not find credentials for the nomitall {nominode_config["nomitall_api_url"]} which the nominode uses, please check {CREDSTORE_PATH} and/or relogin'
+                f'Could not find credentials for the nomitall {nominode_config["nomitall_api_url"]} which the nominode uses, please check {CREDSTORE_PATH} and/or `nnd login --nomitall-url {nominode_config["nomitall_api_url"]}`'
             )
 
         return super().__call__(
